@@ -5,7 +5,8 @@
 #'
 #' @description Produces a table of fit statistics for multiple models.
 #' 
-#' @param fits A series of model object names. Must be a list.
+#' @param fits A series of model object names. 
+#'             Must be a list of model objects or a single model object.
 #' @param plotit If \code{TRUE}, produces plots of the predicted values
 #'               vs. the actual values for each model.
 #' @param digits The number of significant digits in the output.              
@@ -56,7 +57,8 @@
 #'           Here it is expressed as a percent.  That is, a result of 10 = 10%.
 #'           
 #'           Model objects currently supported: lm, glm, nls, betareg, gls,
-#'           lme, lmer, lmerTest, rq, loess, gam, glm.nb, glmRob.
+#'           lme, lmer, lmerTest, glmmTMB, 
+#'           rq, loess, gam, glm.nb, glmRob, rlm.
 #'           
 #'           
 #' @author Salvatore Mangiafico, \email{mangiafico@njaes.rutgers.edu}
@@ -71,6 +73,9 @@
 #' BrendonSmall$Calories = as.numeric(BrendonSmall$Calories)
 #' BrendonSmall$Calories2 = BrendonSmall$Calories ^ 2
 #' model.1 = lm(Sodium ~ Calories, data = BrendonSmall)
+#' 
+#' accuracy(model.1, plotit=FALSE)
+#' 
 #' model.2 = lm(Sodium ~ Calories + Calories2, data = BrendonSmall)
 #' model.3 = glm(Sodium ~ Calories, data = BrendonSmall, family="Gamma")
 #' quadplat = function(x, a, b, clx) {
@@ -79,6 +84,7 @@
 #' model.4 = nls(Sodium ~ quadplat(Calories, a, b, clx),
 #'               data = BrendonSmall,
 #'               start = list(a=519, b=0.359, clx = 2300))
+#'               
 #' accuracy(list(model.1, model.2, model.3, model.4), plotit=FALSE)
 #' 
 #' ### Perfect and poor model fits
@@ -97,6 +103,8 @@
 accuracy = 
 function (fits, plotit=FALSE, digits=3, ...) 
 {
+ if(class(fits)[1]!="list"){fits=list(fits)}
+  
  n = length(fits)
  Y = matrix(rep(NA,n),
             ncol=1)
@@ -194,6 +202,18 @@ function (fits, plotit=FALSE, digits=3, ...)
                                            residuals(fits[[i]], type="response")
                                   call   = fits[[i]]$call
                                   TOGGLE = TRUE}
+   if(class(fits[[i]])[1]=="rlm"){
+                                  predy  = predict(fits[[i]])
+                                  actual = predict(fits[[i]]) + 
+                                  residuals(fits[[i]])
+                                  call   = fits[[i]]$call
+                                  TOGGLE = TRUE}
+   if(class(fits[[i]])[1]=="glmmTMB"){
+                                  predy  = predict(fits[[i]], type="response")
+                                  actual = predict(fits[[i]], type="response") + 
+                                  residuals(fits[[i]], type="response")
+                                  call   = fits[[i]]$call
+                                  TOGGLE = TRUE}
    
     Y[i,] = "Not supported"
 
