@@ -6,6 +6,9 @@
 #' 
 #' @param x A vector of observations.
 #' @param mu The value to compare \code{x} to, as in \code{wilcox.test}
+#' @param adjustn If \code{TRUE}, reduces the sample size in the calculation
+#'                of \code{r} by the number of observations equal to
+#'                \code{mu}.
 #' @param coin If \code{FALSE}, the default, the Z value
 #'                is extracted from a function similar to the
 #'                \code{wilcox.test} function in the stats package.
@@ -34,6 +37,12 @@
 #'           to a vector of \code{mu}.
 #'           The author knows of no reference for this technique.
 #'           
+#'           This statistic typically reports a smaller effect size
+#'           (in absolute value) than does
+#'           the matched-pairs rank biserial correlation coefficient 
+#'           (\code{wilcoxonOneSampleRC}), and may not reach a value
+#'           of -1 or 1 if there are values tied with \code{mu}.
+#'           
 #'           Currently, the function makes no provisions for \code{NA}
 #'           values in the data.  It is recommended that \code{NA}s be removed
 #'           beforehand.
@@ -52,25 +61,30 @@
 #' @concept effect size ordinal nominal
 #' @return A single statistic, r.
 #'         Or a small data frame consisting of r,
-#'         and the lower and upper confidence limits.  
+#'         and the lower and upper confidence limits.
+#'
+#' @section Acknowledgments:
+#'          My thanks to
+#'          Peter Stikker for the suggestion to adjust the sample size
+#'          for ties with \code{mu}.
 #'         
 #' @examples
-#' data(Pooh)
-#' Data = Pooh[Pooh$Time==2,]
-#' wilcox.test(Data$Likert, mu=3, exact=FALSE)
-#' wilcoxonOneSampleR(x = Data$Likert, mu=3)
+#' X = c(1,2,3,3,3,3,4,4,4,4,4,5,5,5,5,5)
+#' wilcox.test(X, mu=3, exact=FALSE)
+#' wilcoxonOneSampleR(X, mu=3)
 #' 
 #' @importFrom coin wilcoxsign_test
 #' @importFrom boot boot boot.ci
 #' 
 #' @export
  
-wilcoxonOneSampleR = function(x, mu=NULL, coin=FALSE,
+wilcoxonOneSampleR = function(x, mu=NULL, adjustn=TRUE, coin=FALSE,
                               ci=FALSE, conf=0.95, type="perc",
                               R=1000, histogram=FALSE, digits=3, ... ){
 
   n  = length(x)
   MU = rep(mu, n)
+  if(adjustn){n = n-sum(x==mu)}
    if(coin){
        WT = suppressWarnings(wilcoxsign_test(x ~ MU, ...))
        Z  = as.numeric(statistic(WT, type="standardized"))
@@ -86,6 +100,7 @@ if(ci==TRUE){
   Function = function(input, index){
                     Input = input[index,]
                     n  = length(Input$x)
+                    if(adjustn){n = n-sum(Input$x==mu)}
                     if(coin){
                        WT = suppressWarnings(wilcoxsign_test(x ~ MU, 
                             data=Input, ...))
